"""
Tests of the IrregularySampledSignal class
"""

try:
    import unittest2 as unittest
except ImportError:
    import unittest

from neo.core.irregularlysampledsignal import IrregularlySampledSignal

class TestIrregularlySampledSignal(unittest.TestCase):
    pass


if __name__ == "__main__":
    unittest.main()
